# -*- coding: utf-8 -*-
"""
Custom `Django Admin actions`_ used in enterprise app.

.. _Django Admin actions: https://docs.djangoproject.com/en/1.8/ref/contrib/admin/actions/
"""
from __future__ import absolute_import, unicode_literals

import unicodecsv
from six import string_types

from django.http import HttpResponse


def export_as_csv_action(description="Export selected objects as CSV file", fields=None, header=True):
    """
    Return an export csv action.

    Arguments:
        description (string): action description
        fields ([string]): list of model fields to include
        header (bool): whether or not to output the column names as the first row
    """
    # adapted from https://gist.github.com/mgerring/3645889
    def export_as_csv(modeladmin, request, queryset):  # pylint: disable=unused-argument
        """
        Export model fields to CSV.
        """
        opts = modeladmin.model._meta

        if not fields:
            field_names = [field.name for field in opts.fields]
        else:
            field_names = fields

        response = HttpResponse(content_type="text/csv")
        response["Content-Disposition"] = "attachment; filename={filename}.csv".format(
            filename=str(opts).replace(".", "_")
        )

        writer = unicodecsv.writer(response, encoding="utf-8")
        if header:
            writer.writerow(field_names)
        for obj in queryset:
            row = []
            for field_name in field_names:
                field = getattr(obj, field_name)
                if callable(field):
                    value = field()
                else:
                    value = field
                if value is None:
                    row.append("[Not Set]")
                elif not value and isinstance(value, string_types):
                    row.append("[Empty]")
                else:
                    row.append(value)
            writer.writerow(row)
        return response

    export_as_csv.short_description = description
    return export_as_csv



# -*- coding: utf-8 -*-
"""
Utilities for Cornerstone integrated channels.
"""

from __future__ import absolute_import, unicode_literals, with_statement

from logging import getLogger

from integrated_channels.cornerstone.models import CornerstoneLearnerDataTransmissionAudit

LOGGER = getLogger(__name__)


def create_cornerstone_learner_data(request, course_id):
    """
        updates or creates CornerstoneLearnerDataTransmissionAudit
    """
    try:
        defaults = {
            'user_guid': request.GET['userGuid'],
            'session_token': request.GET['sessionToken'],
            'callback_url': request.GET['callbackUrl'],
            'subdomain': request.GET['subdomain'],
        }
        CornerstoneLearnerDataTransmissionAudit.objects.update_or_create(
            user_id=request.user.id,
            course_id=course_id,
            defaults=defaults
        )
    except KeyError:
        # if we couldn't find a key, it means we don't want to save data. just skip it by doing nothing.
        pass
    except Exception as ex:  # pylint: disable=broad-except
        LOGGER.error('Unable to Create/Update CornerstoneLearnerDataTransmissionAudit. {ex}'.format(ex=ex))



"""
Management command for assigning enterprise roles to existing enterprise users.
"""
from __future__ import absolute_import, unicode_literals

import logging
from time import sleep

from django.apps import apps
from django.contrib.auth.models import User
from django.core.management.base import BaseCommand, CommandError

from enterprise.constants import (
    EDX_ORG_NAME,
    ENTERPRISE_ADMIN_ROLE,
    ENTERPRISE_CATALOG_ADMIN_ROLE,
    ENTERPRISE_DATA_API_ACCESS_GROUP,
    ENTERPRISE_ENROLLMENT_API_ACCESS_GROUP,
    ENTERPRISE_ENROLLMENT_API_ADMIN_ROLE,
    ENTERPRISE_LEARNER_ROLE,
    ENTERPRISE_OPERATOR_ROLE,
    OAUTH2_PROVIDER_APPLICATION_MODEL,
)
from enterprise.models import (
    EnterpriseCustomerUser,
    EnterpriseFeatureRole,
    EnterpriseFeatureUserRoleAssignment,
    SystemWideEnterpriseRole,
    SystemWideEnterpriseUserRoleAssignment,
)

LOGGER = logging.getLogger(__name__)


class Command(BaseCommand):
    """
    Management command for assigning enterprise roles to existing enterprise users.

    Example usage:
        $ ./manage.py assign_enterprise_user_roles --role=enterprise_admin
        $ ./manage.py assign_enterprise_user_roles --role=enterprise_learner
        $ ./manage.py assign_enterprise_user_roles --role=enterprise_openedx_operator
        $ ./manage.py assign_enterprise_user_roles --role=catalog_admin
        $ ./manage.py assign_enterprise_user_roles --role=enrollment_api_admin
    """
    help = 'Assigns enterprise roles to existing enterprise users.'

    def add_arguments(self, parser):
        """
        Entry point for subclassed commands to add custom arguments.
        """
        parser.add_argument(
            '--role',
            action='store',
            dest='role',
            default=None,
            help='Role to assign users role assignments.'
        )
        parser.add_argument(
            '--batch-limit',
            action='store',
            dest='batch_limit',
            default=100,
            help='Number of users in each batch of conditional offer migration.',
            type=int,
        )

        parser.add_argument(
            '--batch-offset',
            action='store',
            dest='batch_offset',
            default=0,
            help='Which index to start batching from.',
            type=int,
        )

        parser.add_argument(
            '--batch-sleep',
            action='store',
            dest='batch_sleep',
            default=10,
            help='How long to sleep between batches.',
            type=int,
        )

    def _get_enterprise_customer_user_ids(self):
        """
        Returns a queryset containing user ids.
        """
        return EnterpriseCustomerUser.objects.values('user_id')

    def _get_enterprise_admin_users_batch(self, start, end):
        """
        Returns a batched queryset of User objects.
        """
        LOGGER.info('Fetching new batch of enterprise admin users from indexes: %s to %s', start, end)
        return User.objects.filter(groups__name=ENTERPRISE_DATA_API_ACCESS_GROUP, is_staff=False)[start:end]

    def _get_enterprise_operator_users_batch(self, start, end):
        """
        Returns a batched queryset of User objects.
        """
        LOGGER.info('Fetching new batch of enterprise operator users from indexes: %s to %s', start, end)
        return User.objects.filter(groups__name=ENTERPRISE_DATA_API_ACCESS_GROUP, is_staff=True)[start:end]

    def _get_enterprise_customer_users_batch(self, start, end):
        """
        Returns a batched queryset of EnterpriseCustomerUser objects.
        """
        LOGGER.info('Fetching new batch of enterprise customer users from indexes: %s to %s', start, end)
        return User.objects.filter(pk__in=self._get_enterprise_customer_user_ids())[start:end]

    def _get_enterprise_enrollment_api_admin_users_batch(self, start, end):     # pylint: disable=invalid-name
        """
        Returns a batched queryset of User objects.
        """
        LOGGER.info('Fetching new batch of enterprise enrollment admin users from indexes: %s to %s', start, end)
        return User.objects.filter(groups__name=ENTERPRISE_ENROLLMENT_API_ACCESS_GROUP, is_staff=False)[start:end]

    def _get_enterprise_catalog_admin_users_batch(self, start, end):
        """
        Returns a batched queryset of User objects.
        """
        Application = apps.get_model(OAUTH2_PROVIDER_APPLICATION_MODEL)     # pylint: disable=invalid-name
        LOGGER.info('Fetching new batch of enterprise catalog admin users from indexes: %s to %s', start, end)
        catalog_admin_user_ids = Application.objects.filter(
            user_id__in=self._get_enterprise_customer_user_ids()
        ).exclude(name=EDX_ORG_NAME).values('user_id')
        return User.objects.filter(pk__in=catalog_admin_user_ids)[start:end]

    def _assign_enterprise_role_to_users(self, _get_batch_method, options, is_feature_role=False):
        """
        Assigns enterprise role to users.
        """
        role_name = options['role']
        batch_limit = options['batch_limit']
        batch_sleep = options['batch_sleep']
        batch_offset = options['batch_offset']

        current_batch_index = batch_offset

        users_batch = _get_batch_method(
            batch_offset,
            batch_offset + batch_limit
        )

        role_class = SystemWideEnterpriseRole
        role_assignment_class = SystemWideEnterpriseUserRoleAssignment

        if is_feature_role:
            role_class = EnterpriseFeatureRole
            role_assignment_class = EnterpriseFeatureUserRoleAssignment

        enterprise_role = role_class.objects.get(name=role_name)
        while users_batch.count() > 0:
            for index, user in enumerate(users_batch):
                LOGGER.info(
                    'Processing user with index %s and id %s',
                    current_batch_index + index, user.id
                )
                role_assignment_class.objects.get_or_create(
                    user=user,
                    role=enterprise_role
                )

            sleep(batch_sleep)
            current_batch_index += len(users_batch)
            users_batch = _get_batch_method(
                current_batch_index,
                current_batch_index + batch_limit
            )

    def handle(self, *args, **options):
        """
        Entry point for managment command execution.
        """
        LOGGER.info('Starting assigning enterprise roles to users!')

        role = options['role']
        if role == ENTERPRISE_ADMIN_ROLE:
            # Assign admin role to non-staff users with enterprise data api access.
            self._assign_enterprise_role_to_users(self._get_enterprise_admin_users_batch, options)
        elif role == ENTERPRISE_OPERATOR_ROLE:
            # Assign operator role to staff users with enterprise data api access.
            self._assign_enterprise_role_to_users(self._get_enterprise_operator_users_batch, options)
        elif role == ENTERPRISE_LEARNER_ROLE:
            # Assign enterprise learner role to enterprise customer users.
            self._assign_enterprise_role_to_users(self._get_enterprise_customer_users_batch, options)
        elif role == ENTERPRISE_ENROLLMENT_API_ADMIN_ROLE:
            # Assign enterprise enrollment api admin to non-staff users with enterprise data api access.
            self._assign_enterprise_role_to_users(self._get_enterprise_enrollment_api_admin_users_batch, options, True)
        elif role == ENTERPRISE_CATALOG_ADMIN_ROLE:
            # Assign enterprise catalog admin role to users with having credentials in catalog.
            self._assign_enterprise_role_to_users(self._get_enterprise_catalog_admin_users_batch, options, True)
        else:
            raise CommandError('Please provide a valid role name. Supported roles are {admin} and {learner}'.format(
                admin=ENTERPRISE_ADMIN_ROLE,
                learner=ENTERPRISE_LEARNER_ROLE
            ))

        LOGGER.info('Successfully finished assigning enterprise roles to users!')



# -*- coding: utf-8 -*-
# Generated by Django 1.11.25 on 2019-10-24 11:00
from __future__ import unicode_literals

import django.utils.timezone
from django.db import migrations, models

import model_utils.fields

NEW_SOURCES = {
    'Manual Enterprise Enrollment': 'manual',
    'Enterprise API Enrollment': 'enterprise_api',
    'Enterprise Enrollment URL': 'enrollment_url',
    'Enterprise Offer Redemption': 'offer_redemption',
    'Enterprise User B2C Site Enrollment': 'b2c_site',
}


def add_sources(apps, schema_editor):
    enrollment_sources = apps.get_model('enterprise', 'EnterpriseEnrollmentSource')
    for name, slug in NEW_SOURCES.items():
        enrollment_sources.objects.update_or_create(name=name, slug=slug)


def drop_sources(apps, schema_editor):
    enrollment_sources = apps.get_model('enterprise', 'EnterpriseEnrollmentSource')
    enrollment_sources.objects.filter(name__in=NEW_SOURCES).delete()


class Migration(migrations.Migration):

    dependencies = [
        ('enterprise', '0078_auto_20191107_1536'),
    ]

    operations = [
        migrations.CreateModel(
            name='EnterpriseEnrollmentSource',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created', model_utils.fields.AutoCreatedField(
                    default=django.utils.timezone.now,
                    editable=False,
                    verbose_name='created')),
                ('modified', model_utils.fields.AutoLastModifiedField(
                    default=django.utils.timezone.now,
                    editable=False,
                    verbose_name='modified')),
                ('name', models.CharField(max_length=64)),
                ('slug', models.SlugField(max_length=30, unique=True)),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.AddField(
            model_name='enterprisecourseenrollment',
            name='source',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.SET_NULL,
                                    to='enterprise.EnterpriseEnrollmentSource'),
        ),
        migrations.AddField(
            model_name='historicalenterprisecourseenrollment',
            name='source',
            field=models.ForeignKey(blank=True, db_constraint=False, null=True,
                                    on_delete=django.db.models.deletion.DO_NOTHING, related_name='+',
                                    to='enterprise.EnterpriseEnrollmentSource'),
        ),
        migrations.AddField(
            model_name='pendingenrollment',
            name='source',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.SET_NULL,
                                    to='enterprise.EnterpriseEnrollmentSource'),
        ),
        migrations.AddField(
            model_name='historicalpendingenrollment',
            name='source',
            field=models.ForeignKey(blank=True, db_constraint=False, null=True,
                                    on_delete=django.db.models.deletion.DO_NOTHING, related_name='+',
                                    to='enterprise.EnterpriseEnrollmentSource'),
        ),
        migrations.RunPython(add_sources, drop_sources)
    ]



# -*- coding: utf-8 -*-
# Generated by Django 1.11.25 on 2019-10-24 11:00
from __future__ import unicode_literals

import django.utils.timezone
from django.db import migrations, models

import model_utils.fields

NEW_SOURCE_NAME = 'Enterprise management command enrollment'
NEW_SOURCE_SLUG = 'management_command'


def update_source(apps, schema_editor):
    """
    The name of this Source is being updated to better reflect it usage.
    """
    enrollment_sources = apps.get_model('enterprise', 'EnterpriseEnrollmentSource')
    enrollment_sources.objects.create(name=NEW_SOURCE_NAME, slug=NEW_SOURCE_SLUG)


def revert_source(apps, schema_editor):
    """
    The name of this Source is being updated to better reflect it usage.
    """
    enrollment_sources = apps.get_model('enterprise', 'EnterpriseEnrollmentSource')
    enrollment_sources.objects.get(name=NEW_SOURCE_NAME, slug=NEW_SOURCE_SLUG).delete()


class Migration(migrations.Migration):

    dependencies = [
        ('enterprise', '0079_AddEnterpriseEnrollmentSource'),
        ('enterprise', '0081_UpdateEnterpriseEnrollmentSource'),
    ]

    operations = [
        migrations.RunPython(update_source, revert_source)
    ]



# -*- coding: utf-8 -*-
"""
Django management command for migrating EnterpriseCustomerCatalog data to new service.
"""
from __future__ import absolute_import, unicode_literals

import logging

from django.contrib.auth.models import User
from django.core.management.base import BaseCommand, CommandError
from django.utils.translation import ugettext as _

from enterprise.api_client.enterprise_catalog import EnterpriseCatalogApiClient
from enterprise.models import EnterpriseCustomerCatalog

LOGGER = logging.getLogger(__name__)


class Command(BaseCommand):
    """
    Migrate EnterpriseCustomerCatalog data to new Enterprise Catalog service.
    """
    help = 'Migrate EnterpriseCustomerCatalog data to new Enterprise Catalog service.'

    def add_arguments(self, parser):
        parser.add_argument(
            '--api_user',
            dest='api_user',
            required=True,
            metavar='LMS_API_USERNAME',
            help=_('Username of a user authorized to access the Enterprise Catalog API.'),
        )
        super(Command, self).add_arguments(parser)

    def handle(self, *args, **options):
        api_username = options['api_user']
        try:
            user = User.objects.get(username=api_username)
        except User.DoesNotExist:
            raise CommandError(_('A user with the username {username} was not found.').format(username=api_username))

        client = EnterpriseCatalogApiClient(user=user)
        for enterprise_catalog in EnterpriseCustomerCatalog.objects.all():
            LOGGER.info('Migrating Enterprise Catalog {}'.format(enterprise_catalog.uuid))
            try:
                client.create_enterprise_catalog(
                    str(enterprise_catalog.uuid),
                    str(enterprise_catalog.enterprise_customer.uuid),
                    enterprise_catalog.title,
                    enterprise_catalog.content_filter,
                    enterprise_catalog.enabled_course_modes,
                    enterprise_catalog.publish_audit_enrollment_urls
                )
                LOGGER.info('Successfully migrated Enterprise Catalog {}'.format(enterprise_catalog.uuid))
            except Exception:  # pylint: disable=broad-except
                LOGGER.exception('Failed to create enterprise catalog {}'.format(enterprise_catalog.uuid))



# -*- coding: utf-8 -*-
# Generated by Django 1.11.23 on 2019-09-16 15:30
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('enterprise', '0074_auto_20190904_1143'),
    ]

    operations = [
        migrations.AddField(
            model_name='enterprisecustomer',
            name='enable_learner_portal',
            field=models.BooleanField(default=False, help_text='Specifies whether the enterprise learner portal site should be made known to the learner.'),
        ),
        migrations.AddField(
            model_name='enterprisecustomer',
            name='learner_portal_hostname',
            field=models.CharField(blank=True, default='', help_text='Hostname of the enterprise learner portal.', max_length=255),
        ),
        migrations.AddField(
            model_name='historicalenterprisecustomer',
            name='enable_learner_portal',
            field=models.BooleanField(default=False, help_text='Specifies whether the enterprise learner portal site should be made known to the learner.'),
        ),
        migrations.AddField(
            model_name='historicalenterprisecustomer',
            name='learner_portal_hostname',
            field=models.CharField(blank=True, default='', help_text='Hostname of the enterprise learner portal.', max_length=255),
        ),
    ]



# -*- coding: utf-8 -*-
# Generated by Django 1.11.25 on 2019-10-24 11:00
from __future__ import unicode_literals

import django.utils.timezone
from django.db import migrations, models

import model_utils.fields

ORIGINAL_SOURCE_NAME = 'Enterprise User B2C Site Enrollment'
ORIGINAL_SOURCE_SLUG = 'b2c_site'
UPDATED_SOURCE_NAME = 'Enterprise User Enrollment Background Task'
UPDATED_SOURCE_SLUG = 'enrollment_task'


def update_source(apps, schema_editor):
    """
    The name of this Source is being updated to better reflect it usage.
    """
    enrollment_sources = apps.get_model('enterprise', 'EnterpriseEnrollmentSource')

    source = enrollment_sources.objects.get(slug=ORIGINAL_SOURCE_SLUG)
    source.name = UPDATED_SOURCE_NAME
    source.slug = UPDATED_SOURCE_SLUG
    source.save()


def revert_source(apps, schema_editor):
    """
    The name of this Source is being updated to better reflect it usage.
    """
    enrollment_sources = apps.get_model('enterprise', 'EnterpriseEnrollmentSource')

    source = enrollment_sources.objects.get(slug=UPDATED_SOURCE_SLUG)
    source.name = ORIGINAL_SOURCE_NAME
    source.slug = ORIGINAL_SOURCE_SLUG
    source.save()


class Migration(migrations.Migration):

    dependencies = [
        ('enterprise', '0079_AddEnterpriseEnrollmentSource'),
        ('enterprise', '0080_auto_20191113_1708'),
    ]

    operations = [
        migrations.RunPython(update_source, revert_source)
    ]



# -*- coding: utf-8 -*-

"""
Statements base for xAPI.
"""
from __future__ import absolute_import, unicode_literals

from tincan import Activity, ActivityDefinition, Agent, LanguageMap, Statement

from integrated_channels.xapi.constants import X_API_ACTIVITY_COURSE


class EnterpriseStatement(Statement):
    """
    Base statement for enterprise events.
    """

    def get_actor(self, user, user_social_auth):
        """
        Get actor for the statement.
        """
        social_auth_uid = user_social_auth.uid if user_social_auth else ''
        sso_id = social_auth_uid.split(':')[-1]
        name = sso_id if sso_id else user.email
        return Agent(
            name=name,
            mbox=u'mailto:{email}'.format(email=user.email),
        )

    def get_object(self, course_overview):
        """
        Get object for the statement.
        """
        name = (course_overview.display_name or '').encode("ascii", "ignore").decode('ascii')
        description = (course_overview.short_description or '').encode("ascii", "ignore").decode('ascii')

        return Activity(
            id=course_overview.id,
            definition=ActivityDefinition(
                type=X_API_ACTIVITY_COURSE,
                name=LanguageMap({'en-US': name}),
                description=LanguageMap({'en-US': description}),
            ),
        )



# -*- coding: utf-8 -*-
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('enterprise', '0051_add_enterprise_slug'),
    ]

    operations = [
        migrations.AlterField(
            model_name='enterprisecustomer',
            name='slug',
            field=models.SlugField(default='default', help_text='A short string uniquely identifying this enterprise. Cannot contain spaces and should be a usable as a CSS class. Examples: "ubc", "mit-staging"', unique=True, max_length=30),
        ),
        migrations.AlterField(
            model_name='historicalenterprisecustomer',
            name='slug',
            field=models.SlugField(default='default', help_text='A short string uniquely identifying this enterprise. Cannot contain spaces and should be a usable as a CSS class. Examples: "ubc", "mit-staging"', max_length=30),
        ),
    ]



# -*- coding: utf-8 -*-
# Generated by Django 1.11.23 on 2019-09-04 16:43
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('enterprise', '0073_enterprisecustomerreportingconfiguration_uuid'),
    ]

    operations = [
        migrations.AddField(
            model_name='enterprisecourseenrollment',
            name='marked_done',
            field=models.BooleanField(default=False, help_text='Specifies whether a user marked this course as completed in the learner portal.'),
        ),
        migrations.AddField(
            model_name='historicalenterprisecourseenrollment',
            name='marked_done',
            field=models.BooleanField(default=False, help_text='Specifies whether a user marked this course as completed in the learner portal.'),
        ),
    ]



# -*- coding: utf-8 -*-
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('enterprise', '0034_auto_20171023_0727'),
    ]

    operations = [
        migrations.AddField(
            model_name='enterprisecustomercatalog',
            name='publish_audit_enrollment_urls',
            field=models.BooleanField(default=False, help_text='Specifies whether courses should be published with direct-to-audit enrollment URLs.'),
        ),
        migrations.AddField(
            model_name='historicalenterprisecustomercatalog',
            name='publish_audit_enrollment_urls',
            field=models.BooleanField(default=False, help_text='Specifies whether courses should be published with direct-to-audit enrollment URLs.'),
        ),
    ]



# -*- coding: utf-8 -*-
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('enterprise', '0035_auto_20171212_1129'),
    ]

    operations = [
        migrations.AddField(
            model_name='enterprisecustomerreportingconfiguration',
            name='sftp_file_path',
            field=models.CharField(help_text='If the delivery method is sftp, the path on the host to deliver the report to.', max_length=256, null=True, verbose_name='SFTP file path', blank=True),
        ),
        migrations.AddField(
            model_name='enterprisecustomerreportingconfiguration',
            name='sftp_hostname',
            field=models.CharField(help_text='If the delivery method is sftp, the host to deliver the report to.', max_length=256, null=True, verbose_name='SFTP Host name', blank=True),
        ),
        migrations.AddField(
            model_name='enterprisecustomerreportingconfiguration',
            name='sftp_password',
            field=models.BinaryField(max_length=256, blank=True, help_text='If the delivery method is sftp, the password to use to securely access the host.', null=True, verbose_name='SFTP password'),
        ),
        migrations.AddField(
            model_name='enterprisecustomerreportingconfiguration',
            name='sftp_port',
            field=models.PositiveIntegerField(default=22, help_text='If the delivery method is sftp, the port on the host to connect to.', null=True, verbose_name='SFTP Port', blank=True),
        ),
        migrations.AddField(
            model_name='enterprisecustomerreportingconfiguration',
            name='sftp_username',
            field=models.CharField(help_text='If the delivery method is sftp, the username to use to securely access the host.', max_length=256, null=True, verbose_name='SFTP username', blank=True),
        ),
        migrations.AlterField(
            model_name='enterprisecustomerreportingconfiguration',
            name='delivery_method',
            field=models.CharField(default='email', help_text='The method in which the data should be sent.', max_length=20, verbose_name='Delivery Method', choices=[('email', 'email'), ('sftp', 'sftp')]),
        ),
        migrations.AlterField(
            model_name='enterprisecustomerreportingconfiguration',
            name='password',
            field=models.BinaryField(verbose_name='Password for the protected zip file.', max_length=256),
        ),
    ]



# -*- coding: utf-8 -*-
"""
Client for communicating with the Enterprise API.
"""

from __future__ import absolute_import, unicode_literals

import json
from logging import getLogger

from django.conf import settings

from enterprise.api_client.lms import JwtLmsApiClient

LOGGER = getLogger(__name__)


class EnterpriseCatalogApiClient(JwtLmsApiClient):
    """
    Object builds an API client to make calls to the Enterprise Catalog API.
    """

    API_BASE_URL = settings.ENTERPRISE_CATALOG_INTERNAL_ROOT_URL + '/api/v1/'
    ENTERPRISE_CATALOG_ENDPOINT = 'enterprise-catalog'
    APPEND_SLASH = True

    @JwtLmsApiClient.refresh_token
    def create_enterprise_catalog(
            self,
            catalog_uuid,
            enterprise_id,
            title,
            content_filter,
            enabled_course_modes,
            publish_audit_enrollment_urls):
        """Creates an enterprise catalog."""
        endpoint = getattr(self.client, self.ENTERPRISE_CATALOG_ENDPOINT)
        post_data = {
            'uuid': catalog_uuid,
            'title': title,
            'enterprise_customer': enterprise_id,
            'content_filter': json.dumps(content_filter),
            'enabled_course_modes': json.dumps(enabled_course_modes),
            'publish_audit_enrollment_urls': json.dumps(publish_audit_enrollment_urls),
        }
        return endpoint.post(post_data)

    @JwtLmsApiClient.refresh_token
    def get_enterprise_catalog(self, catalog_uuid):
        """Gets an enterprise catalog."""
        endpoint = getattr(self.client, self.ENTERPRISE_CATALOG_ENDPOINT)(catalog_uuid)
        return endpoint.get()

    @JwtLmsApiClient.refresh_token
    def update_enterprise_catalog(self, catalog_uuid, **kwargs):
        """Updates an enterprise catalog."""
        endpoint = getattr(self.client, self.ENTERPRISE_CATALOG_ENDPOINT)(catalog_uuid)
        return endpoint.put(kwargs)

    @JwtLmsApiClient.refresh_token
    def delete_enterprise_catalog(self, catalog_uuid):
        """Deletes an enterprise catalog."""
        endpoint = getattr(self.client, self.ENTERPRISE_CATALOG_ENDPOINT)(catalog_uuid)
        return endpoint.delete()
